# TSMetrics

Welcome!

While building millions of time series models on daily basis I used various commonly used evaluation metrics. I thought putting all of them together as a package could be beneficial for like wise users.

## Installation

You can pip install it straight from git:
```
pip install git+git://
```
